summaryrefslogtreecommitdiff
path: root/gtk2_ardour/option_editor.h
diff options
context:
space:
mode:
authorCarl Hetherington <carl@carlh.net>2012-06-19 22:05:04 +0000
committerCarl Hetherington <carl@carlh.net>2012-06-19 22:05:04 +0000
commit1173bae7c20e1d7763ae092b1b98c92835b1562f (patch)
treee40aea1f6c5c3ea5c1c032500f255c07d102398e /gtk2_ardour/option_editor.h
parent46f594ac839e81d3e9eee821084f22290a0cc61f (diff)
Clarify the meaning of the show-region-gain-envelopes option.
git-svn-id: svn://localhost/ardour2/branches/3.0@12790 d708f5d6-7413-0410-9779-e7cbd77b26cf
Diffstat (limited to 'gtk2_ardour/option_editor.h')
-rw-r--r--gtk2_ardour/option_editor.h33
1 files changed, 32 insertions, 1 deletions
diff --git a/gtk2_ardour/option_editor.h b/gtk2_ardour/option_editor.h
index 5d6a48a024..b896411a71 100644
--- a/gtk2_ardour/option_editor.h
+++ b/gtk2_ardour/option_editor.h
@@ -192,7 +192,7 @@ private:
};
/** Component which provides the UI to handle an enumerated option using a GTK CheckButton.
* The template parameter is the enumeration.
*/
template <class T>
@@ -273,6 +273,37 @@ private:
};
+/** Component which provides the UI to handle a boolean option which needs
+ * to be represented as a ComboBox to be clear to the user.
+ */
+class BoolComboOption : public Option
+{
+public:
+
+ BoolComboOption (
+ std::string const &,
+ std::string const &,
+ std::string const &,
+ std::string const &,
+ sigc::slot<bool>,
+ sigc::slot<bool, bool>
+ );
+
+ void set_state_from_config ();
+ void add_to_page (OptionEditorPage *);
+ void changed ();
+ void set_sensitive (bool);
+
+private:
+
+ sigc::slot<bool> _get;
+ sigc::slot<bool, bool> _set;
+ Gtk::Label* _label;
+ Gtk::ComboBoxText* _combo;
+};
+
+
+
/** Component which provides the UI to handle an numeric option using a GTK SpinButton */
template <class T>
class SpinOption : public Option
@@ -192,7 +192,7 @@ private:
};
-/** Component which provides the UI to handle an enumerated option using a GTK CheckButton.
+/** Component which provides the UI to handle an enumerated option using a GTK ComboBox.
* The template parameter is the enumeration.
*/